#!/usr/local/bin/wish -f

# Copyright(c) 1998, Space Science and Engineering Center, UW-Madison
# Refer to "McIDAS Software Acquisition and Distribution Policies"
# in the file  mcidas/data/license.txt

# $Id: CursorConfig.tcl,v 1.12 2004/03/18 22:51:51 tsmith Exp $

#===================================================================================#
# reference notes
#
#     Relevant Global variables:
#	CursorType	-- 1 Box
#			-- 2 Crosshair
#			-- 3 Box and Crosshair
#			-- 4 Solid Box
#		Accessed -- UserCommon cursor_type if 0 check 76 for saved type
#
#	CursorColor	-- red/green/blue value in format "#xxxxxx"
#		Accessed -- UserCommon cursor_color 32 bit format rgbX
#
#	CursorWidth	-- Width of cursor in pixels
#		Accessed -- UserCommon cursor_horiz_size
#
#	CursorHeight  	-- Height of cursor in pixels
#		Accessed -- UserCommon cursor_vert_size
#
#    Procedures list:
# 	McSetCursor       -- Sets User Common values to change the cursor
# 	SetAndDrawCursor  -- Sets cursor H/W and draws to canvas
# 	DrawCursor        -- Draws cursor to Canvas
# 	ToggleLock        -- Reads the CursorLockXY variable and toggles it 
# 	SizeEntered       -- Captures text resizing of cursor
#       CreateCursorIcons -- Creates button icons from mmencode strings
#====================================================================================#

#----------------------------------------------------------------------
# CursorAttributes
#----------------------------------------------------------------------
proc CursorAttributes { } \
{ 
   global tk_version
   global CursorType
   global CursorWidth
   global CursorMaxWidth
   global CursorHeight
   global CursorMaxHeight
   global CursorColor
   global CursorBackgroundColor
   global icon_xhair
   global icon_box
   global icon_xbox
   global icon_solid
   global icon_locked
   global icon_unlocked
   global OldType
   global OldColor
   global OldWidth
   global OldHeight
   global OrgType
   global OrgColor
   global OrgWidth
   global OrgHeight
   global CursorLockXY

   if { [winfo exists .tlCursor] } \
   { 
	wm deiconify .tlCursor
	focus .tlCursor
	raise .tlCursor
	return
   }

  #-- Create button icons
    CreateCursorIcons

  #-- Access user common to restore Cursor values
    set CursorType [UCpeek cursor_type]

    # if deactive restore type from "saved" location
    if {!$CursorType} { set CursorType [UCpeek 76] }

    set OldType $CursorType
    set OldColor $CursorColor
         
    set CursorBackgroundColor #111111
    set CursorWidth [UCpeek cursor_horiz_size]
    set CursorHeight [UCpeek cursor_vert_size]
    set OldWidth $CursorWidth
    set OldHeight $CursorHeight

  # Remember original settings in case the user hits 'Cancel'
    set OrgType   $CursorType
    set OrgColor  $CursorColor
    set OrgHeight $CursorHeight
    set OrgWidth  $CursorWidth

    set CursorMaxHeight 299
    set CursorMaxWidth  299
    if {$CursorWidth == $CursorHeight } { set CursorLockXY 1 } else { set CursorLockXY 0 }

  # -- set the color by breaking down the 32 bit value,
  #    color held in most significant 24 bits in RGB format
    set CursorColor [format "#%02x%02x%02x" [expr ([UCpeek cursor_color] >> 24) & 255] \
                                            [expr ([UCpeek cursor_color] >> 16) & 255] \
					                [expr ([UCpeek cursor_color] >> 8) & 255]]

  #-- Setting up the main window here
  toplevel .tlCursor
  wm title .tlCursor "Cursor Attributes"
  .tlCursor configure \
	-relief raised \
	-borderwidth 2
  wm geometry .tlCursor +100+100
  wm resizable .tlCursor no no

  frame .tlCursor.mainFrame \
    -borderwidth 2 \
    -relief raised 

     # -- here's the canvas    
     canvas .tlCursor.mainFrame.canvasCursor \
	-height $CursorMaxHeight \
	-width $CursorMaxWidth \
	-background $CursorBackgroundColor \
	-highlightthickness 0 \
	-relief sunken \
	-borderwidth 2

     #-- frame for the buttons on the right
     frame .tlCursor.mainFrame.frameButtons

     #-- frame for 'cursor type' radio buttons (don't use labelframe 
     #   TK version is old)
     if { [expr {$tk_version < 8.4}] } \
     {
        frame .tlCursor.mainFrame.frameButtons.radioButtonFrame \
	   -relief groove \
	   -borderwidth 2
     } \
     else \
     {
        labelframe .tlCursor.mainFrame.frameButtons.radioButtonFrame \
	   -text "Type" \
	   -labelanchor n \
	   -relief groove \
	   -borderwidth 2
      }

        #-- now the buttons
           radiobutton .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonXHair \
             -highlightthickness 0 \
             -image icon_xhair \
             -width 30 \
             -height 22 \
             -variable "CursorType" \
             -value 2 \
	     -indicatoron no \
	     -selectcolor grey80 \
             -command { DrawCursor $CursorWidth $CursorHeight $CursorBackgroundColor $OldType
          	        set OldType $CursorType
          	        DrawCursor $CursorWidth $CursorHeight $CursorColor $CursorType }
           grid .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonXHair \
             -row 0 \
	     -column 0 \
	     -padx 2 \
	     -pady 2

           radiobutton .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonBox \
             -highlightthickness 0 \
             -image icon_box \
             -width 30 \
             -height 22 \
             -variable "CursorType" \
             -value 1 \
	     -indicatoron no \
	     -selectcolor grey80 \
             -command { DrawCursor $CursorWidth $CursorHeight $CursorBackgroundColor $OldType
          	        set OldType $CursorType
          	        DrawCursor $CursorWidth $CursorHeight $CursorColor $CursorType }
      	   grid .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonBox \
             -row 0 \
	     -column 1 \
	     -padx 2 \
	     -pady 2

           radiobutton .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonXBox \
             -highlightthickness 0 \
             -image icon_xbox \
             -width 30 \
             -height 22 \
             -variable "CursorType" \
             -value 3 \
	     -indicatoron no \
	     -selectcolor grey80 \
             -command { DrawCursor $CursorWidth $CursorHeight $CursorBackgroundColor $OldType
          	        set OldType $CursorType
          	        DrawCursor $CursorWidth $CursorHeight $CursorColor $CursorType }
           grid .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonXBox \
             -row 1 \
	     -column 0 \
	     -padx 2 \
	     -pady 2

           radiobutton .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonSolid \
             -highlightthickness 0 \
             -image icon_solid \
             -width 30 \
             -height 22 \
             -variable "CursorType" \
             -value 4 \
	     -indicatoron no \
	     -selectcolor grey80 \
             -command { DrawCursor $CursorWidth $CursorHeight $CursorBackgroundColor $OldType
          	        set OldType $CursorType
          	        DrawCursor $CursorWidth $CursorHeight $CursorColor $CursorType }
           grid .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonSolid \
             -row 1 \
	     -column 1 \
	     -padx 2 \
	     -pady 2

      #--- Color menu button

           menubutton .tlCursor.mainFrame.frameButtons.color \
             -text "Color" \
             -indicatoron yes \
             -relief raised \
             -borderwidth 2 \
             -menu .tlCursor.mainFrame.frameButtons.color.menu
           menu .tlCursor.mainFrame.frameButtons.color.menu \
             -tearoff no

           FILL_COLOR_MENU .tlCursor.mainFrame.frameButtons.color

      #--- Cursor size controls(don't use labelframe 
      #   TK version is old)
      	if { [expr {$tk_version < 8.4}] } \
      	{
         frame .tlCursor.mainFrame.frameButtons.sizeFrame \
	   -relief groove \
	   -borderwidth 2
      	} \
      	else \
	{
         labelframe .tlCursor.mainFrame.frameButtons.sizeFrame \
	   -text "Size" \
	   -labelanchor n \
	   -relief groove \
	   -borderwidth 2
	}
	pack .tlCursor.mainFrame.frameButtons.radioButtonFrame \
             -fill x \
	     -ipady 5
 
	   scale .tlCursor.mainFrame.frameButtons.sizeFrame.height \
		-label "Height:" \
		-variable CursorHeight \
		-from 1 \
		-to $CursorMaxHeight \
		-orient horizontal \
		-width 6 \
		-sliderlength 15 \
		-highlightthickness 0 \
		-command {SizeEntered HEIGHT}
	   grid .tlCursor.mainFrame.frameButtons.sizeFrame.height \
                -row 0 \
                -column 0 \
		-columnspan 2 \
                -padx 5 \
                -sticky e

	   scale .tlCursor.mainFrame.frameButtons.sizeFrame.width \
		-label "Width:" \
		-variable CursorWidth \
		-from 1 \
		-to $CursorMaxWidth \
		-orient horizontal \
		-width 6 \
		-sliderlength 15 \
		-highlightthickness 0 \
		-command {SizeEntered WIDTH}
	   grid .tlCursor.mainFrame.frameButtons.sizeFrame.width \
                -row 1 \
                -column 0 \
		-columnspan 2 \
                -padx 5 \
		-pady 5 \
                -sticky e

           message .tlCursor.mainFrame.frameButtons.sizeFrame.aspectLabel \
             -text "Aspect\nRatio:" \
             -justify left
           grid .tlCursor.mainFrame.frameButtons.sizeFrame.aspectLabel \
             -row 2 \
             -column 0

            button .tlCursor.mainFrame.frameButtons.sizeFrame.aspectRatioLock \
             -highlightthickness 0 \
             -relief raised \
             -width 22 \
             -height 22 \
             -command ToggleLock
           grid .tlCursor.mainFrame.frameButtons.sizeFrame.aspectRatioLock \
             -row 2 \
             -column 1 \
             -padx 5 \
             -pady 5 \
             -sticky e

     #--- Restore defaults button
            button .tlCursor.mainFrame.defaults \
              -text "Restore Default Settings" \
              -command "set CursorType 2
                        set CursorWidth 31
                        set CursorHeight 31
                        set CursorColor #ff0000
                        SetAndDrawCursor 31 31
                        .tlCursor.mainFrame.frameButtons.radioButtonFrame.buttonXHair invoke"

      #--- Now pack the color menu button
        pack .tlCursor.mainFrame.frameButtons.color \
             -side top \
             -pady 10 \
             -fill x

      #--- Now pack the size controls
        pack .tlCursor.mainFrame.frameButtons.sizeFrame \
             -side top  \
             -fill x \
	     -ipadx 5 \
	     -ipady 5

      #--- Now pack the canvas and the buttons frame as well
        grid .tlCursor.mainFrame.canvasCursor \
             -row 0 \
             -column 0 \
             -padx 5 \
             -pady 3

        grid .tlCursor.mainFrame.frameButtons \
             -row 0 \
             -column 1 \
             -padx 5 \
             -pady 5

        grid .tlCursor.mainFrame.defaults \
             -row 1 \
             -column 0 \
             -columnspan 2 \
             -sticky ew \
             -padx 5 \
             -pady 3

     # --- Some button configuration stuff here (Is it already locked etc...)
       if  {$CursorLockXY} \
       {
         .tlCursor.mainFrame.frameButtons.sizeFrame.aspectRatioLock config \
             -image icon_locked
       } \
       else \
       {         
         .tlCursor.mainFrame.frameButtons.sizeFrame.aspectRatioLock config \
             -image icon_unlocked
       }

     pack .tlCursor.mainFrame \
	-side top \
	-fill x \
	-padx 2 \
	-pady 2
     
     frame .tlCursor.frameOKCancel 

     button  .tlCursor.frameOKCancel.buttonOK \
	-highlightthickness 0 \
	-text "OK" \
	-relief raised \
	-width 8 \
	-command { McSetCursor
	           SaveContext
	           destroy .tlCursor }
     button  .tlCursor.frameOKCancel.buttonCancel \
	-highlightthickness 0 \
	-text "Cancel" \
	-relief raised \
	-width 8 \
	-command { ResetCursorSpecs
	           destroy .tlCursor }

     pack .tlCursor.frameOKCancel.buttonOK \
	-side left \
	-padx 5
     pack .tlCursor.frameOKCancel.buttonCancel \
	-side left \
	-padx 5
     pack .tlCursor.frameOKCancel \
	-side top \
	-pady 5
   #-- do the bindings here for the canvas
     bind .tlCursor.mainFrame.canvasCursor <B1-Motion> { SetAndDrawCursor %x %y }
     bind .tlCursor.mainFrame.canvasCursor <Button-1> { SetAndDrawCursor %x %y }

   #-- now show the cursor before beginning (border adjustment in routine--need to remove)
     SetAndDrawCursor $CursorWidth $CursorHeight
}   


#-------------------------------------------------------------------#
# ResetCursorSpecs - Reset the cursor specifications                #
#-------------------------------------------------------------------#
proc ResetCursorSpecs { } \
{
   global CursorType
   global CursorWidth
   global CursorHeight
   global CursorColor
   global OrgType
   global OrgColor
   global OrgWidth
   global OrgHeight

   set CursorType   $OrgType
   set CursorColor  $OrgColor
   set CursorHeight $OrgHeight
   set CursorWidth  $OrgWidth
}


#-------------------------------------------------------------------#
# McSetCursor -- sets User Common values to change the cursor       #
#-------------------------------------------------------------------#
proc McSetCursor { } \
{
   global CursorType
   global CursorWidth
   global CursorHeight
   global CursorColor

   scan $CursorColor "#%02x%02x%02x" r g b
   RunCommand "CUR $CursorHeight $CursorWidth $CursorType $b $g $r"
} 


#----------------------------------------------------------------------------#
# SetAndDrawCursor { XLoc YLoc } -- based on XLoc and YLoc and whether or    #
#	 not the CursorLockXY is set the size of the Cursor is adjusted and  #
#	 DrawCursor is called to correctly draw the cursor	                 #
#	-- XLoc -- X location of the mouse pointer in the canvas	         #
#	-- YLoc -- Y location of the mouse pointer in the canvas	         #
#----------------------------------------------------------------------------#
proc SetAndDrawCursor { XLoc YLoc } \
{ 
  global CursorLockXY CursorWidth CursorHeight CursorColor OldWidth OldHeight OldType CursorType CursorBackgroundColor

  if { [string match $XLoc "X"] } { set XLoc $CursorWidth  }
  if { [string match $YLoc "X"] } { set YLoc $CursorHeight }

  #-- clear the old cursor 
    DrawCursor $OldWidth $OldHeight $CursorBackgroundColor $OldType
         
  #-- make sure size is >= 1 
    if {$XLoc < 1 } {set XLoc 1}
    if {$YLoc < 1 } {set YLoc 1}
        
  #-- make sure XLoc is an odd number
    if { ! [expr $XLoc % 2] } \
    {
	if { [expr $CursorWidth > $OldWidth] } \
	{
	    incr XLoc
	} \
	else \
	{
	    incr XLoc -1
	}
    }

  #-- make sure YLoc is an odd number
    if { ! [expr $YLoc % 2] }  \
    {
	if { [expr $CursorHeight > $OldHeight] } \
	{
	    incr YLoc
	} \
	else \
	{
	    incr YLoc -1
	}
    }
      
  #-- Now either keep XLoc=YLoc or let range
    if { $CursorLockXY } \
    {
	if { $XLoc > $YLoc} \
 	{
	   set YLoc $XLoc
	} \
	else \
	{
	   set XLoc $YLoc
	}
    }
            
  #-- update Width and Height Variables
    set CursorWidth $XLoc
    set CursorHeight $YLoc
         
  #-- set Old values so when erasing the cursor the range is correct
    set OldWidth $CursorWidth
    set OldHeight $CursorHeight

  #-- finally draw the new cursor 
    DrawCursor $CursorWidth $CursorHeight $CursorColor $CursorType  
}


#-------------------------------------------------------------------#
# DrawCursor { w h color type } -- routine that updates canvas with 
#                                  correct cursor size
#	-- w -- width of the cursor
#	-- h -- height of the cursor
#	-- color -- color to draw the cursor
#	-- type  -- type of cursor to draw
#	     = 1  -- BOX
#	     = 2  -- XHAIR
#	     = 3  -- XBOX
#	     = 4  -- SOLID
#-------------------------------------------------------------------#
proc DrawCursor { w h color type } \
{
  global CursorMaxHeight
  global CursorMaxWidth

  #-- set up coordinates -- easy access -- need to add 2 for border 
  #-- allow entry of cursor size larger then 255 but only display up to 255
  if { $w > $CursorMaxWidth } { set w $CursorMaxWidth }
  if { $h > $CursorMaxHeight } { set h $CursorMaxHeight }

  set x1 0
  set x2 $w
  set xmid [expr $w / 2]

  set y1 0
  set y2 $h 
  set ymid [expr $h / 2]

  #-- based on type -- draw the cursor now
  switch -exact $type \
  {
    1 \
    {
      .tlCursor.mainFrame.canvasCursor create rect $x1 $y1 $x2 $y2 \
	  -outline $color
    }

    2 \
    {
      .tlCursor.mainFrame.canvasCursor create line $xmid $y1 $xmid $y2 \
	  -fill $color
      .tlCursor.mainFrame.canvasCursor create line $x1 $ymid $x2 $ymid \
	  -fill $color
    }

    3 \
    {
      .tlCursor.mainFrame.canvasCursor create rect $x1 $y1 $x2 $y2 \
	  -outline $color
      .tlCursor.mainFrame.canvasCursor create line $xmid $y1 $xmid $y2 \
	  -fill $color
      .tlCursor.mainFrame.canvasCursor create line $x1 $ymid $x2 $ymid \
	  -fill $color
    }

    4 \
    {
      .tlCursor.mainFrame.canvasCursor create rect $x1 $y1 $x2 $y2 \
	  -fill $color \
	  -outline $color
    }
  }   
}


#----------------------------------------------------------------------------
# ToggleLock { } -- Reads the CursorLockXY variable and toggles it as well
#                   as the button picture
#----------------------------------------------------------------------------
proc ToggleLock { } \
{
  global CursorLockXY
      
  if { $CursorLockXY } \
  {
    #-- Unlock it
    set CursorLockXY 0
    .tlCursor.mainFrame.frameButtons.sizeFrame.aspectRatioLock config \
	-image icon_unlocked 
  } \
  else \
  {  
    #-- Lock it
    set CursorLockXY 1
    .tlCursor.mainFrame.frameButtons.sizeFrame.aspectRatioLock config \
	-image icon_locked 
  }
}


#----------------------------------------------------------------------
# SizeEntered { ToAlter size } -- cursor size was entered in an entry 
#                                 field so adjust it here
#----------------------------------------------------------------------
proc SizeEntered { ToAlter size } \
{
  global OldWidth OldHeight OldType CursorWidth CursorHeight CursorLockXY
  global CursorBackgroundColor

  #-- first of all erase the old cursor
    DrawCursor $OldWidth $OldHeight $CursorBackgroundColor $OldType

  #-- set width = height if the lock is on
    if { $CursorLockXY } \
    {
	set CursorWidth $size
	set CursorHeight $size
    } \
    else \
    {
	if { [string match $ToAlter "HEIGHT"] } \
	{
	    set CursorHeight $size
	} \
	elseif { [string match $ToAlter "WIDTH"] } \
	{
	    set CursorWidth $size
	}
    }

  #-- draw the new cursor
    SetAndDrawCursor $CursorWidth $CursorHeight
}
 


#----------------------------------------------------------------------
# FILL_COLOR_MENU -- fill the color menu with available graphics colors
#----------------------------------------------------------------------
proc FILL_COLOR_MENU { menu_button } \
{
   global color_table
   global num_colors
   global color_level
   global CursorColor
   global CursorHeight
   global CursorWidth
   global CursorType

   # Get current color information
   set inputOperator [open "|gu.k TABLE" r]
   gets $inputOperator line; # header line
   gets $inputOperator line; # header line
   set num_colors 0
   while {[gets $inputOperator line] >= 0} \
   {
	if {[string compare [lindex $line 1] "Done"] == 0} {break}

	# Insert 'User-Defined' if no name for color is given
	if {[expr {[llength $line] < 5}] == 1} \
	{
	   set line [linsert $line 1 "User-Defined"]
	}

	set color_table([lindex $line 0]) $line
	incr num_colors
   }
   catch {close $inputOperator}

   for {set i 1} {$i < $num_colors} {incr i} \
   {
	$menu_button.menu add command \
	   -label "[lindex $color_table($i) 0] [lindex $color_table($i) 1]" \
   	   -background [format "#%02x%02x%02x" \
			[lindex $color_table($i) 4] \
			[lindex $color_table($i) 3] \
			[lindex $color_table($i) 2]] \
   	   -activebackground [format "#%02x%02x%02x" \
			[lindex $color_table($i) 4] \
			[lindex $color_table($i) 3] \
			[lindex $color_table($i) 2]] \
	   -command "set color_level [lindex $color_table($i) 0]
		     set color_name [lindex $color_table($i) 1]
		     set CursorColor [format "#%02x%02x%02x" \
			   			  	 [lindex $color_table($i) 4] \
			   				 [lindex $color_table($i) 3] \
			   				 [lindex $color_table($i) 2]]
                     SetAndDrawCursor X X"
   }
}


#----------------------------------------------------------------------
# CreateCursorIcons - create button icons using mmencode strings
#----------------------------------------------------------------------
proc CreateCursorIcons { } \
{
   global icon_xhair
   global icon_box
   global icon_xbox
   global icon_solid
   global icon_locked
   global icon_unlocked

   # Create xhair icon
   image create photo icon_xhair \
	-data {
R0lGODlhEAAQAPcAAAAAAAEBAQICAgMDAwQEBAUFBQYGBgcHBwgICAkJCQoKCgsLCwwMDA0N
DQ4ODg8PDxAQEBERERISEhMTExQUFBUVFRYWFhcXFxgYGBkZGRoaGhsbGxwcHB0dHR4eHh8f
HyAgICEhISIiIiMjIyQkJCUlJSYmJicnJygoKCkpKSoqKisrKywsLC0tLS4uLi8vLzAwMDEx
MTIyMjMzMzQ0NDU1NTY2Njc3Nzg4ODk5OTo6Ojs7Ozw8PD09PT4+Pj8/P0BAQEFBQUJCQkND
Q0REREVFRUZGRkdHR0hISElJSUpKSktLS0xMTE1NTU5OTk9PT1BQUFFRUVJSUlNTU1RUVFVV
VVZWVldXV1hYWFlZWVpaWltbW1xcXF1dXV5eXl9fX2BgYGFhYWJiYmNjY2RkZGVlZWZmZmdn
Z2hoaGlpaWpqamtra2xsbG1tbW5ubm9vb3BwcHFxcXJycnNzc3R0dHV1dXZ2dnd3d3h4eHl5
eXp6ent7e3x8fH19fX5+fn9/f4CAgIGBgYKCgoODg4SEhIWFhYaGhoeHh4iIiImJiYqKiouL
i4yMjI2NjY6Ojo+Pj5CQkJGRkZKSkpOTk5SUlJWVlZaWlpeXl5iYmJmZmZqampubm5ycnJ2d
nZ6enp+fn6CgoKGhoaKioqOjo6SkpKWlpaampqenp6ioqKmpqaqqqqurq6ysrK2tra6urq+v
r7CwsLGxsbKysrOzs7S0tLW1tba2tre3t7i4uLm5ubq6uru7u7y8vL29vb6+vr+/v8DAwMHB
wcLCwsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvLy8zMzM3Nzc7Ozs/Pz9DQ0NHR0dLS0tPT
09TU1NXV1dbW1tfX19jY2NnZ2dra2tvb29zc3N3d3d7e3t/f3+Dg4OHh4eLi4uPj4+Tk5OXl
5ebm5ufn5+jo6Onp6erq6uvr6+zs7O3t7e7u7u/v7/Dw8PHx8fLy8vPz8/T09PX19fb29vf3
9/j4+Pn5+fr6+vv7+/z8/P39/f7+/v///yH5BAEAAOUALAAAAAAQABAAQAg5AMsJHFgOAACC
Aw0qXMjQIEKBDh9KjCgRIcWKCQ9iJHhxY0eMHyuGnKjRYsOTIUc+VGlyI8eSBAMCADs=
	}


   image create photo icon_xbox \
	-data {
R0lGODlhEAAQAPcAAAAAAAEBAQICAgMDAwQEBAUFBQYGBgcHBwgICAkJCQoKCgsLCwwMDA0N
DQ4ODg8PDxAQEBERERISEhMTExQUFBUVFRYWFhcXFxgYGBkZGRoaGhsbGxwcHB0dHR4eHh8f
HyAgICEhISIiIiMjIyQkJCUlJSYmJicnJygoKCkpKSoqKisrKywsLC0tLS4uLi8vLzAwMDEx
MTIyMjMzMzQ0NDU1NTY2Njc3Nzg4ODk5OTo6Ojs7Ozw8PD09PT4+Pj8/P0BAQEFBQUJCQkND
Q0REREVFRUZGRkdHR0hISElJSUpKSktLS0xMTE1NTU5OTk9PT1BQUFFRUVJSUlNTU1RUVFVV
VVZWVldXV1hYWFlZWVpaWltbW1xcXF1dXV5eXl9fX2BgYGFhYWJiYmNjY2RkZGVlZWZmZmdn
Z2hoaGlpaWpqamtra2xsbG1tbW5ubm9vb3BwcHFxcXJycnNzc3R0dHV1dXZ2dnd3d3h4eHl5
eXp6ent7e3x8fH19fX5+fn9/f4CAgIGBgYKCgoODg4SEhIWFhYaGhoeHh4iIiImJiYqKiouL
i4yMjI2NjY6Ojo+Pj5CQkJGRkZKSkpOTk5SUlJWVlZaWlpeXl5iYmJmZmZqampubm5ycnJ2d
nZ6enp+fn6CgoKGhoaKioqOjo6SkpKWlpaampqenp6ioqKmpqaqqqqurq6ysrK2tra6urq+v
r7CwsLGxsbKysrOzs7S0tLW1tba2tre3t7i4uLm5ubq6uru7u7y8vL29vb6+vr+/v8DAwMHB
wcLCwsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvLy8zMzM3Nzc7Ozs/Pz9DQ0NHR0dLS0tPT
09TU1NXV1dbW1tfX19jY2NnZ2dra2tvb29zc3N3d3d7e3t/f3+Dg4OHh4eLi4uPj4+Tk5OXl
5ebm5ufn5+jo6Onp6erq6uvr6+zs7O3t7e7u7u/v7/Dw8PHx8fLy8vPz8/T09PX19fb29vf3
9/j4+Pn5+fr6+vv7+/z8/P39/f7+/v///yH5BAEAAOUALAAAAAAQABAAQAg7AAEIHEiwoMGD
BsspVChwIcOBDss1dEgw4sSFFSkCsAhRI0eEIEMe5Phxo0eNIkeexNiRZUmSKFMODAgAOw==
	}


   image create photo icon_box \
	-data {
R0lGODlhEAAQAPcAAAAAAAEBAQICAgMDAwQEBAUFBQYGBgcHBwgICAkJCQoKCgsLCwwMDA0N
DQ4ODg8PDxAQEBERERISEhMTExQUFBUVFRYWFhcXFxgYGBkZGRoaGhsbGxwcHB0dHR4eHh8f
HyAgICEhISIiIiMjIyQkJCUlJSYmJicnJygoKCkpKSoqKisrKywsLC0tLS4uLi8vLzAwMDEx
MTIyMjMzMzQ0NDU1NTY2Njc3Nzg4ODk5OTo6Ojs7Ozw8PD09PT4+Pj8/P0BAQEFBQUJCQkND
Q0REREVFRUZGRkdHR0hISElJSUpKSktLS0xMTE1NTU5OTk9PT1BQUFFRUVJSUlNTU1RUVFVV
VVZWVldXV1hYWFlZWVpaWltbW1xcXF1dXV5eXl9fX2BgYGFhYWJiYmNjY2RkZGVlZWZmZmdn
Z2hoaGlpaWpqamtra2xsbG1tbW5ubm9vb3BwcHFxcXJycnNzc3R0dHV1dXZ2dnd3d3h4eHl5
eXp6ent7e3x8fH19fX5+fn9/f4CAgIGBgYKCgoODg4SEhIWFhYaGhoeHh4iIiImJiYqKiouL
i4yMjI2NjY6Ojo+Pj5CQkJGRkZKSkpOTk5SUlJWVlZaWlpeXl5iYmJmZmZqampubm5ycnJ2d
nZ6enp+fn6CgoKGhoaKioqOjo6SkpKWlpaampqenp6ioqKmpqaqqqqurq6ysrK2tra6urq+v
r7CwsLGxsbKysrOzs7S0tLW1tba2tre3t7i4uLm5ubq6uru7u7y8vL29vb6+vr+/v8DAwMHB
wcLCwsPDw8TExMXFxcbGxsfHx8jIyMnJycrKysvLy8zMzM3Nzc7Ozs/Pz9DQ0NHR0dLS0tPT
09TU1NXV1dbW1tfX19jY2NnZ2dra2tvb29zc3N3d3d7e3t/f3+Dg4OHh4eLi4uPj4+Tk5OXl
5ebm5ufn5+jo6Onp6erq6uvr6+zs7O3t7e7u7u/v7/Dw8PHx8fLy8vPz8/T09PX19fb29vf3
9/j4+Pn5+fr6+vv7+/z8/P39/f7+/v///yH5BAEAAOUALAAAAAAQABAAQAg2AAEIHEiw4MBy
CBMqREhwocNyDR8qjCiR4cGKFgVizGiwo8ePFzFSrDhSYsmHJx2mXAjSY0AAADs=
	}

   image create photo icon_solid \
	-data {
R0lGODlhEAAQAPcAAAAAAP//////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
/////////////////////////////////ywAAAAAEAAQAEAIHQABCBxIsKDBgwgTKlzIsKHD
hxAjSpxIsaLFgQEBADs=
	}   

   image create photo icon_locked \
	-data {
R0lGODlhDgAPAPcAAAAAAOfn5///////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
/////////////////////////////////yH5BAEAAAEALAAAAAAOAA8AQAg4AAMEAECwoEGB
BhMmHAhAoEOHBBkelFiQ4cOHES1eRNhwIUSFIBeGnJhxY8aSFyOOXMmSZEuQAQEAOw==
	}

   image create photo icon_unlocked \
	-data {
R0lGODlhDgAPAPcAAAAAAOfn5///////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////
/////////////////////////////////yH5BAEAAAEALAAAAAAOAA8AQAg4AAMEAECwoEGB
BhMmFMiwIUIAAxdGPBjR4UOLDgk+LNhQoUeFFzNqxNgRIkmGGj+qXOlxI0uFAQEAOw==
	}
}


# ------------ END OF FILE --------------------------------------------------------------

