# Copyright(c) 1998, Space Science and Engineering Center, UW-Madison
# Refer to "McIDAS Software Acquisition and Distribution Policies"
# in the file  mcidas/data/license.txt

# $Id: listdataset.tcl,v 1.15 1998/10/13 20:26:39 dglo Exp $

# ListDataset w
#
# Create a top-level window containing a listbox showing a bunch of
# datasets
#
# Arguments:
#
#    w		Name to use for new top-level window.
#

proc ListDataset { group datatype getpos thevar {w .listdataset}} {

# 	Verify that the user is logged on before continuing
	if { [VerifyLoggedOn $datatype $group] == 0} { return }

#
#	Let user know this will take a while.
#
	showBusyStatus
#
#	Create a popup widget for listing enhancement table names.
#

	catch {destroy $w}
	toplevel $w
	wm title $w "Datasets of type $datatype for group:$group"
	wm iconname $w "Datasets"
	wm minsize $w 1 1
	placepopup $w

	message $w.msg -font -Adobe-times-medium-r-normal--*-180* -aspect 900 \
	    -text "Double click to select dataset."

	frame $w.frame -borderwidth 10
	scrollbar $w.frame.scroll -relief sunken -command "$w.frame.list yview"
	listbox $w.frame.list -yscroll "$w.frame.scroll set" -relief sunken \
		-width 80 -height 10 -setgrid 1

	pack append $w.frame $w.frame.scroll {right filly} \
		$w.frame.list {left expand fill}
#
#	Get the table names and put them in the listbox.
#
	set lalist [open "|dsinfo.k $datatype $group" r]
	gets $lalist temp
	gets $lalist temp
	gets $lalist temp
	gets $lalist lab1
	label $w.label1 -width 80  -text $lab1  -anchor w
	gets $lalist lab2
	label $w.label2 -width 80  -text $lab2 -anchor w
	while {[gets $lalist line] > -1} {
#
#		Don't put the Done message into the box.
#
		if {[string first done $line] == -1} {
#
#			Don't put the linked message into the box.
#
			if { [string first linked $line] == -1} {
#
#				Extract the file name.  Insert in listbox.
#
				set filename [string range $line 0 80]
				$w.frame.list insert end $filename
			}
		}
	}
	catch {close $lalist}
#
#	Select a table by double clicking.
#
	bind $w.frame.list <Double-1> "doit $group $thevar $getpos $datatype"
#
#	Dismiss button.
#
	button $w.ok -text Dismiss -command "destroy $w" -width 20

	pack $w.msg -side top -fill both
	pack $w.label1  -side top
	pack $w.frame -side top
	pack $w.ok -side bottom

#
#	Let user know we're done.
#
	showIdleStatus
}
proc doit {group thevar getpos datatype} {
	set areal [selection get]

	 set dataset [string range $areal 0 \
		[expr [string first " " $areal ] -1 ] ]
	 set fullname [format "%s/%s" $group $dataset]
	 destroy .listdataset
	 upvar $getpos posvar
	 if {$posvar == "YES"} {
		if {$datatype == "IMAGE"} {

		# if listing images and we want to get destination,
		# just fill in the name - they will have to fill in
		# the position manually
			if {$thevar == "dest"} {
			   global $thevar
			   set $thevar $fullname
			}
			ListImage $fullname $thevar
		}
		if {$datatype == "GRID"} {
			if {$thevar == "dest"} {
			   global $thevar
			   set $thevar $fullname
			}
			ListGridFile $fullname $thevar
			}
	 } else {
		global $thevar
		set $thevar $fullname
	 }
}
