# Copyright(c) 1998, Space Science and Engineering Center, UW-Madison
# Refer to "McIDAS Software Acquisition and Distribution Policies"
# in the file  mcidas/data/license.txt

# $Id: listgrid.tcl,v 1.13 1998/10/13 20:26:40 dglo Exp $

# ListImage w
#
# Create a top-level window containing a listbox showing a bunch of
# enhancement table names.
#
# Arguments:
#
#    w		Name to use for new top-level window.
#

proc ListGrid { gridfile  thevar {w .listgrid}} {

#
#	Let user know this will take a while.
#
	showBusyStatus
#
#	Create a popup widget for listing enhancement table names.
#
	catch {destroy $w}
	toplevel $w
	wm title $w "Grids"
	wm iconname $w "Grids"
	wm minsize $w 1 1
	placepopup $w
	if {$thevar == "src"} {
	   message $w.msg -font -Adobe-times-medium-r-normal--*-180* \
		-aspect 900 \
		-text "Click to select Grid, or click and drag to select range. To select highlighted items, Press OK."
	} else {
	   message $w.msg -font -Adobe-times-medium-r-normal--*-180* \
	    -aspect 900 \
	    -text "Double click to select Grid."
	}

	frame $w.frame -borderwidth 10
	scrollbar $w.frame.scroll -relief sunken -command "$w.frame.list yview"
	listbox $w.frame.list -yscroll "$w.frame.scroll set" -relief sunken \
		-width 84 -height 10 -setgrid 1
	if {$thevar == "src"} {
		$w.frame.list configure -selectmode extended
	}


	pack append $w.frame $w.frame.scroll {right filly} \
		$w.frame.list {left expand fill}
#
#	Get the table names and put them in the listbox.
#

	set lalist [open "|grdlist.k $gridfile NUM=ALL" r]
	gets $lalist lab1
	label $w.label1 -width 84 -text $lab1
	gets $lalist lab2
	label $w.label2 -width 84 -text $lab2 -anchor w
	gets $lalist junk
	while {[gets $lalist line] > -1} {

#
#		Don't put the Done message into the box.
#
		if {[string first done $line] == -1} {
		if {[string first listed $line] == -1} {
#
#			Don't put the linked message into the box.
#
			if { [string first linked $line] == -1} {
#
#				Extract the file name.  Insert in listbox.
#
				set filename [string range $line 0 80]
				$w.frame.list insert end $filename
			}
		}
		}
	}
	catch {close $lalist}
#
#	Select a table by double clicking.
#
	if {$thevar != "src"} {
	   bind $w.frame.list <Double-1> \
		{set areal [selection get]
		 set gridnumber [string range $areal 70 75]
		 global gridnumber
		 set gridnumber [string trim $gridnumber]
		 global unit
		 set unit ""
		 destroy .listgrid
	   }
	}
#
#	Dismiss button.
#
	frame $w.bottom
	if {$thevar == "src"} {
	   button $w.bottom.ok  -text OK -width 20 -command {
		global bgrid
		global egrid
		set ilist [.listgrid.frame.list curselection]
		set first [lindex $ilist 0]
		set firstlist [.listgrid.frame.list get $first]
		set bgrid [string range $firstlist 70 75]
		set ilast [expr [llength $ilist] -1]
		set last [lindex $ilist $ilast]
		set lastlist [.listgrid.frame.list get $last]
		set egrid [string range $lastlist 70 75]
		set bgrid [string trim $bgrid]
		set egrid [string trim $egrid]
		destroy .listgrid}
	   pack $w.bottom.ok -side left
	}
	button $w.bottom.dismiss -text Dismiss -command "destroy $w" -width 20

	pack $w.msg -side top -fill both
	pack $w.label1 -side top
	pack $w.label2 -side top
	pack $w.frame -side top
	if {$thevar == "src"} {
		pack $w.bottom.dismiss -side right
	} else {
		pack $w.bottom.dismiss -side bottom
	}
	pack $w.bottom -side bottom -fill both -expand yes
#
#	Let user know we're done.
#
	showIdleStatus
}
